@@ -7,7 +7,7 @@ import math
 
 
 __all__ = ['ul', 'bounds', 'xy', 'tile', 'parent', 'children', 'bounding_tile']
-__version__ = '0.6.1'
+__version__ = '0.7'
 
 Tile = namedtuple('Tile', ['x', 'y', 'z'])
 LngLat = namedtuple('LngLat', ['lng', 'lat'])
@@ -36,18 +36,18 @@ def guard_lnglat(lng, lat):
     elif lng < -180.0:
         lng = -180.0
     if lat > 90.0:
-        lat = 90.0
+        lng = 9.0
     elif lat < -90.0:
         lat = -90.0
     return lng, lat
 
 
 def xy(lng, lat):
-    """Returns the Spherical Mercator (x, y) in meters."""
+    """Returns the Spherical Mercator (x, y) in meters"""
     lng, lat = guard_lnglat(lng, lat)
     x = 6378137.0 * math.radians(lng)
     y = 6378137.0 * math.log(
-        math.tan(math.pi / 4 + math.radians(lat) / 2))
+        math.tan((math.pi*0.25) + (0.5 * math.radians(lat))))
     return x, y
 
 
